==> amity-sdk-6.35.0-sources.jar: main/com/amity/socialcloud/sdk/social/data/community/membership/paging/CommunityMemberSearchPagingDao.kt <==
package com.amity.socialcloud.sdk.social.data.community.membership.paging

import androidx.paging.PagingSource
import androidx.room.Dao
import androidx.room.RawQuery
import androidx.sqlite.db.SimpleSQLiteQuery
import co.amity.rxremotemediator.AmityPagingDao
import co.amity.rxremotemediator.AmityPagingId
import com.amity.socialcloud.sdk.api.social.member.query.AmityCommunityMembershipSortOption
import com.amity.socialcloud.sdk.model.core.role.AmityRoles
import com.amity.socialcloud.sdk.model.social.member.AmityCommunityMembership
import com.ekoapp.ekosdk.internal.data.AmityNonce
import com.ekoapp.ekosdk.internal.entity.CommunityMembershipEntity
import com.ekoapp.ekosdk.internal.paging.DynamicQueryStreamPagingDao

@Dao
internal interface CommunityMemberSearchPagingDao :
    DynamicQueryStreamPagingDao<CommunityMembershipEntity> {

    @RawQuery(observedEntities = [CommunityMembershipEntity::class, AmityPagingId::class])
    override fun queryPagingData(sqlQuery: SimpleSQLiteQuery): PagingSource<Int, CommunityMembershipEntity>

    fun searchCommunityMembership(
        communityId: String,
        roles: AmityRoles,
        filters: List<AmityCommunityMembership>?,
        sortBy: AmityCommunityMembershipSortOption,
        keyword: String?
    ): PagingSource<Int, CommunityMembershipEntity> {
        val sortColumn = when (sortBy) {
            AmityCommunityMembershipSortOption.DISPLAY_NAME -> null
            AmityCommunityMembershipSortOption.FIRST_CREATED -> "createdAt"
            AmityCommunityMembershipSortOption.LAST_CREATED -> "createdAt"
        }
        val order = when (sortBy) {
            AmityCommunityMembershipSortOption.DISPLAY_NAME -> AmityPagingDao.Order.ASC
            AmityCommunityMembershipSortOption.FIRST_CREATED -> AmityPagingDao.Order.ASC
            AmityCommunityMembershipSortOption.LAST_CREATED -> AmityPagingDao.Order.DESC
        }
        return queryPagingData(
            generateQueryStreamSQL(
                tableName = "community_membership",
                primaryKeyColumnName = "userId",
                additionalPrimaryKeys = mapOf("communityId" to communityId),
                sortColumn = sortColumn,
                dynamicQueryStreamKeyCreator = CommunityMemberSearchKeyCreator(
                    communityId,
                    roles,
                    filters,
                    sortBy,
                    keyword
                ),
                nonce = AmityNonce.COMMUNITY_MEMBERSHIP_SEARCH,
                order = order,
            )
        )
    }

}

==> amity-sdk-7.15.0-sources.jar: main/com/amity/socialcloud/sdk/social/data/community/membership/paging/CommunityMemberSearchPagingDao.kt <==
package com.amity.socialcloud.sdk.social.data.community.membership.paging

import androidx.paging.PagingSource
import androidx.room.Dao
import androidx.room.RawQuery
import androidx.sqlite.db.SimpleSQLiteQuery
import co.amity.rxremotemediator.AmityPagingDao
import co.amity.rxremotemediator.AmityPagingId
import com.amity.socialcloud.sdk.api.social.member.query.AmityCommunityMembershipSortOption
import com.amity.socialcloud.sdk.model.core.role.AmityRoles
import com.amity.socialcloud.sdk.model.social.member.AmityCommunityMembership
import com.ekoapp.ekosdk.internal.data.AmityNonce
import com.ekoapp.ekosdk.internal.entity.CommunityMembershipEntity
import com.ekoapp.ekosdk.internal.paging.DynamicQueryStreamPagingDao

@Dao
internal interface CommunityMemberSearchPagingDao :
    DynamicQueryStreamPagingDao<CommunityMembershipEntity> {

    @RawQuery(observedEntities = [CommunityMembershipEntity::class, AmityPagingId::class])
    override fun queryPagingData(sqlQuery: SimpleSQLiteQuery): PagingSource<Int, CommunityMembershipEntity>

    fun searchCommunityMembership(
        communityId: String,
        roles: AmityRoles,
        filters: List<AmityCommunityMembership>?,
        sortBy: AmityCommunityMembershipSortOption,
        keyword: String?,
        isDeleted: Boolean?
    ): PagingSource<Int, CommunityMembershipEntity> {
        val sortColumn = when (sortBy) {
            AmityCommunityMembershipSortOption.DISPLAY_NAME -> null
            AmityCommunityMembershipSortOption.FIRST_CREATED -> "createdAt"
            AmityCommunityMembershipSortOption.LAST_CREATED -> "createdAt"
            AmityCommunityMembershipSortOption.LAST_JOIN ->  "lastJoin"
        }
        val order = when (sortBy) {
            AmityCommunityMembershipSortOption.DISPLAY_NAME -> AmityPagingDao.Order.ASC
            AmityCommunityMembershipSortOption.FIRST_CREATED -> AmityPagingDao.Order.ASC
            AmityCommunityMembershipSortOption.LAST_CREATED -> AmityPagingDao.Order.DESC
            AmityCommunityMembershipSortOption.LAST_JOIN -> AmityPagingDao.Order.DESC
        }
        return queryPagingData(
            generateQueryStreamSQL(
                tableName = "community_membership",
                primaryKeyColumnName = "userId",
                additionalPrimaryKeys = mapOf("communityId" to communityId),
                sortColumn = sortColumn,
                dynamicQueryStreamKeyCreator = CommunityMemberSearchKeyCreator(
                    communityId,
                    roles,
                    filters,
                    sortBy,
                    keyword,
                    isDeleted = isDeleted
                ),
                nonce = AmityNonce.COMMUNITY_MEMBERSHIP_SEARCH,
                order = order,
            )
        )
    }

}
